complete_current_script: Fill in the middle or complete

View source: R/complete_current_script.R

complete_current_scriptR Documentation

Fill in the middle or complete

Description

This function splits the current script into two parts: the part before the cursor and the part after the cursor.

Usage

complete_current_script()

Value

A character vector containing the two parts of the script.


codestral documentation built on June 8, 2025, 10:53 a.m.