View source: R/complete_current_script.R
| complete_current_script | R Documentation |
This function splits the current script into two parts: the part before the cursor and the part after the cursor.
complete_current_script()
A character vector containing the two parts of the script.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.